djangocms-table
===============

A Table Plugin for django CMS.


Installation
------------

This plugin requires `django CMS` 2.3 or higher to be properly installed.

* In your projects `virtualenv`_, run ``pip install djangocms-table``.
* Add ``'djangocms_table'`` to your ``INSTALLED_APPS`` setting.
* Run ``manage.py migrate cmsplugin_table``.


Kudos
-----

This plugin contains the handsontable.com jquery library.
Thanks to notch-interactive.com as well for some code examples.


Translations
------------

If you want to help translate the plugin please do it on transifex:

https://www.transifex.com/projects/p/django-cms/resource/djangocms-table/

